//LabPlot : SmoothListDialog.h

#ifndef SMOOTHLISTDIALOG_H
#define SMOOTHLISTDIALOG_H

#include "ListDialog.h"

class SmoothListDialog : public ListDialog
{
	Q_OBJECT
public:
	SmoothListDialog(MainWin *mw, const char *name);
public slots:
	void setNumber(int n) {nle->setText(QString::number(n)); }	//!< set number to smooth
private:
	KLineEdit *nle;
private slots:
	int apply_clicked();
};

#endif // SMOOTHLISTDIALOG_H
